pub fn binary_search<T: Measure + PartialEnum, U, V, I: AsRef<Item<AnyRange<T>, V>>>(
items: &[I],
element: &U,
connected: bool,
) -> Option<usize>where
U: RangePartialOrd<T>,Expand description
Search for the index of the gratest item less/below or equal/including the given element.
If connected is true, then it will search for the gratest item less/below or equal/including or connected to the given element.